@@ -22,22 +22,22 @@ pub trait Vec2Ext {
 }
 
 impl Vec2Ext for Vec2 {
-    fn step(self, edge: Vec2) -> Vec2 {
+    fn step(self, edge: Self) -> Self {
         vec2(self.x.step(edge.x), self.y.step(edge.y))
     }
 
-    fn step_select(self, edge: Vec2, less: Vec2, greater_or_equal: Vec2) -> Vec2 {
+    fn step_select(self, edge: Self, less: Self, greater_or_equal: Self) -> Self {
         vec2(
             self.x.step_select(edge.x, less.x, greater_or_equal.x),
             self.y.step_select(edge.y, less.y, greater_or_equal.y),
         )
     }
 
-    fn fract(self) -> Vec2 {
+    fn fract(self) -> Self {
         vec2(self.x.fract(), self.y.fract())
     }
 
-    fn saturate(self) -> Vec2 {
+    fn saturate(self) -> Self {
         vec2(self.x.saturate(), self.y.saturate())
     }
 }
