@@ -15,7 +15,7 @@ pub trait Vec4Ext {
 }
 
 impl Vec4Ext for Vec4 {
-    fn sqrt(self) -> Vec4 {
+    fn sqrt(self) -> Self {
         vec4(self.x.sqrt(), self.y.sqrt(), self.z.sqrt(), self.w.sqrt())
     }
 
